==> nextcloud-app-deck-1%3A1.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ko.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "덱",
    "Personal" : "개인",
    "The card \"%s\" on \"%s\" has reached its due date." : "카드 \"%s\"(\"%s\"에 있음)의 만료 날짜가 다가왔습니다.",
    "The board \"%s\" has been shared with you by %s." : "\"%s\" 게시판을 %s 님이 공유했습니다.",
    "{user} has shared the board %s with you." : "{user} 님이 %s 게시판을 공유했습니다.",
    "Finished" : "완료됨",
    "To review" : "리뷰할 항목",
    "Action needed" : "동작 필요",
    "Later" : "나중에",
    "copy" : "복사",
    "Done" : "완료",
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "Create new board" : "새 게시판 만들기",
    "Cancel" : "취소",
    "File already exists" : "파일이 이미 존재함",
    "Do you want to overwrite it?" : "덮어쓰시겠습니까?",
    "Overdue" : "기한 넘김",
    "Show archived cards" : "보관된 카드 보기",
    "Details" : "세부사항",
    "Sharing" : "공유",
    "Tags" : "태그",
    "Undo" : "실행 취소",
    "(Group)" : "(그룹)",
    "Can edit" : "편집할 수 있음",
    "Can share" : "공유할 수 있음",
    "Delete" : "삭제",
    "Add a new stack" : "새 스택 추가",
    "Delete list" : "목록 지우기",
    "Add card" : "카드 추가",
    "Edit" : "편집",
    "Due date" : "만료 날짜",
    "Remove due date" : "만료 날짜 삭제",
    "Description" : "설명",
    "Formatting help" : "서식 도움말",
    "Attachments" : "첨부파일",
    "Comments" : "댓글",
    "Modified" : "수정한 날짜",
    "Created" : "생성됨",
    "Upload attachment" : "첨부 파일 업로드",
    "Save" : "저장",
    "Reply" : "답장",
    "Update" : "업데이트",
    "(group)" : "(그룹)",
    "seconds ago" : "초 전",
    "Delete card" : "카드 삭제",
    "Move card" : "카드 이동",
    "Archived boards" : "보관된 게시판",
    "Shared boards" : "공유된 게시판",
    "Settings" : "설정",
    "New board title" : "새 게시판 제목",
    "Share" : "공유",
    "Edit board" : "게시판 편집",
    "An error occurred" : "오류가 발생함",
    "Archive board" : "게시판 보관",
    "Unarchive board" : "게시판 보관 해제",
    "Delete board" : "게시판 삭제",
    "Board details" : "게시판 정보"
},
"nplurals=1; plural=0;");

==> nextcloud-app-deck-1%3A1.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ko.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "새로운 보드{board}를 만들었습니다.",
    "Deck" : "덱",
    "Personal" : "개인",
    "The card \"%s\" on \"%s\" has reached its due date." : "카드 \"%s\"(\"%s\"에 있음)의 만료 날짜가 다가왔습니다.",
    "The board \"%s\" has been shared with you by %s." : "\"%s\" 게시판을 %s 님이 공유했습니다.",
    "{user} has shared the board %s with you." : "{user} 님이 %s 게시판을 공유했습니다.",
    "Finished" : "완료됨",
    "To review" : "리뷰할 항목",
    "Action needed" : "동작 필요",
    "Later" : "나중에",
    "copy" : "복사",
    "To do" : "할 일",
    "Done" : "완료",
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "Create new board" : "새 게시판 만들기",
    "new board" : "새로운 보드",
    "Search by board title" : "보드 제목으로 검색",
    "Select board" : "보드 선택",
    "Select the card to link to a project" : "카드를 선택해 프로젝트에 연결",
    "Select a board" : "보드 선택",
    "Select a card" : "카드 선택",
    "Cancel" : "취소",
    "File already exists" : "파일이 이미 존재함",
    "A file with the name {filename} already exists." : "이미 존재하는  파일이름 {filename} ",
    "Do you want to overwrite it?" : "덮어쓰시겠습니까?",
    "Overwrite file" : "덮어쓰기",
    "Keep existing file" : "기존 파일 보존",
    "This board is read only" : "읽기 전용 보드",
    "Drop your files to upload" : "업로드를 하려면 파일을 올리시오.",
    "Add new list" : "새로운 리스트 추가",
    "List name" : "리스트 추가",
    "Apply filter" : "필터링 적용",
    "Filter by tag" : "태그로 필터링",
    "Overdue" : "기한 넘김",
    "Next 24 hours" : "다음 24시간",
    "Show archived cards" : "보관된 카드 보기",
    "Details" : "세부사항",
    "Sharing" : "공유",
    "Tags" : "태그",
    "Deleted items" : "삭제된 항목",
    "Undo" : "실행 취소",
    "(Group)" : "(그룹)",
    "Can edit" : "편집할 수 있음",
    "Can share" : "공유할 수 있음",
    "Delete" : "삭제",
    "Add a new stack" : "새 스택 추가",
    "Delete list" : "목록 지우기",
    "Add card" : "카드 추가",
    "Edit" : "편집",
    "Title" : "직위",
    "Members" : "구성원",
    "Due date" : "만료 날짜",
    "Remove due date" : "만료 날짜 삭제",
    "Description" : "설명",
    "Formatting help" : "서식 도움말",
    "Attachments" : "첨부파일",
    "Comments" : "댓글",
    "Modified" : "수정한 날짜",
    "Created" : "생성됨",
    "Upload attachment" : "첨부 파일 업로드",
    "Save" : "저장",
    "Reply" : "답장",
    "Update" : "업데이트",
    "(group)" : "(그룹)",
    "seconds ago" : "초 전",
    "Archive card" : "보관 카드",
    "Delete card" : "카드 삭제",
    "Move card" : "카드 이동",
    "Card details" : "카드 세부사항",
    "All boards" : "모든 보드",
    "Archived boards" : "보관된 게시판",
    "Shared with you" : "나와 공유됨",
    "Settings" : "설정",
    "New board title" : "새 게시판 제목",
    "Edit board" : "게시판 편집",
    "Board details" : "게시판 정보",
    "An error occurred" : "오류가 발생함",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "정말로 보드 {title}을 지우시겠습니까? 보드의 모든 데이터가 삭제됩니다.",
    "Delete the board?" : "보드를 삭제합니까?",
    "Something went wrong" : "잘못된 접근"
},
"nplurals=1; plural=0;");
